{% load staticfiles %}
{% load i18n %}
{% load otree %}

<!DOCTYPE html>
<html lang="en">
<head>
    <title>{% block head_title %}{% block title %}
    {% endblock %}{% endblock %}</title>

    <meta name="description"
          content="otree">
    <meta name="keywords"
          content="otree">

    {% block internal_styles %}
        <meta name="viewport" content="width=device-width, initial-scale=1.0">

        {% block bootstrap_styles %}
        <link rel="stylesheet"
              href="{% static 'bootstrap4/css/bootstrap.min.css' %}">

        <link rel="stylesheet"
              href="{% static 'bootstrap4/css/bootstrap-reboot.min.css' %}">
        {% endblock %}

        <link rel="stylesheet" href="{% static 'otree/css/theme.css' %}">

        {# this actually belongs in internal_scripts, but we are in the process #}
        {# of deprecating it, so some people's apps might still rely on jQuery being #}
        {# available within the content block. #}
        <script src="{% static 'otree/js/jquery-3.2.1.min.js' %}"></script>


    {% endblock %}
    {% block global_styles %}
    {% endblock %}
    {% block app_styles %}
    {% endblock %}
    {# 'styles' block is for page-specific styles (for 3rd party programmers only) #}
    {% block styles %}
    {% endblock %}
</head>
<body>
{% block body_main %}{% endblock %}

{% block internal_scripts %}
    <script src="{% static 'otree/js/reconnecting-websocket.js' %}" type="text/javascript"></script>
    {% block bootstrap_scripts %}
    <script src="{% static 'bootstrap4/js/bootstrap.bundle.min.js' %}"></script>
    {% endblock %}
    <script src="{% static 'otree/js/init_widgets.js' %}"></script>
{% endblock %}
{% block global_scripts %}
{% endblock %}
{% block app_scripts %}
{% endblock %}
{# 'scripts' block is for page-specific scripts (for 3rd party programmers only) #}
{% block scripts %}
{% endblock %}
</body>
</html>
